==> mysql-connector-java-6.0.3-sources.jar: com/mysql/cj/api/x/FindStatement.java <==
/*
  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.api.x;

import com.mysql.cj.x.json.DbDoc;

/**
 * A statement to <i>find</i> the set of documents according to the given specification.
 */
public interface FindStatement extends DataStatement<FindStatement, DocResult, DbDoc> {
    /**
     * Add/replace the field projection defining the result.
     */
    FindStatement fields(String projection);

    /**
     * Add/replace the field projection defining the result.
     */
    FindStatement fields(Expression docProjection);

    /**
     * Add/replace the aggregation fields for this query.
     */
    FindStatement groupBy(String groupBy);

    /**
     * Add/replace the aggregate criteria for this query.
     */
    FindStatement having(String having);

    /**
     * Add/replace the order specification for this query.
     */
    FindStatement orderBy(String sortFields);

    /**
     * Add/replace the document offset for this query.
     */
    FindStatement skip(long limitOffset);

    /**
     * Add/replace the document limit for this query.
     */
    FindStatement limit(long numberOfRows);
}

==> mysql-connector-java-6.0.5-sources.jar: com/mysql/cj/api/x/FindStatement.java <==
/*
  Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.api.x;

import com.mysql.cj.x.json.DbDoc;

/**
 * A statement to <i>find</i> the set of documents according to the given specification.
 */
public interface FindStatement extends DataStatement<FindStatement, DocResult, DbDoc> {
    /**
     * Add/replace the field projections defining the result.
     */
    FindStatement fields(String... projections);

    /**
     * Add/replace the field projection defining the result.
     */
    FindStatement fields(Expression docProjection);

    /**
     * Add/replace the aggregation fields for this query.
     */
    FindStatement groupBy(String... groupBy);

    /**
     * Add/replace the aggregate criteria for this query.
     */
    FindStatement having(String having);

    /**
     * Add/replace the order specification for this query.
     */
    FindStatement orderBy(String... sortFields);

    /**
     * Add/replace the order specification for this query.
     * <p>
     * Synonym for {@link #orderBy(String...)}
     */
    FindStatement sort(String... sortFields);

    /**
     * Add/replace the document offset for this query.
     */
    FindStatement skip(long limitOffset);

    /**
     * Add/replace the document limit for this query.
     */
    FindStatement limit(long numberOfRows);
}
